;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "string-inflection" "20251114.1041"
  "Foo_bar => FOO_BAR => FooBar => fooBar => foo-bar => Foo_Bar => foo_bar conversion of names."
  ()
  :url "https://github.com/akicho8/string-inflection"
  :commit "072f7dff43140570788d64ac0ec9d930c3c2a96b"
  :revdesc "072f7dff4314"
  :keywords '("elisp")
  :authors '(("akicho8" . "akicho8@gmail.com"))
  :maintainers '(("akicho8" . "akicho8@gmail.com")))
